@@ -22,22 +22,35 @@ class Fisica(object):
     "Representa un simulador de mundo fisico, usando la biblioteca box2d."
     
     def __init__(self, area, gravedad=(0, -90)):
+        self.area = area
         try:
             self.escenario = box2d.b2AABB()
             self.escenario.lowerBound = (-1000.0, -1000.0)
             self.escenario.upperBound = (1000.0, 1000.0)
             self.gravedad = box2d.b2Vec2(gravedad[0], gravedad[1])
-            self.mundo = box2d.b2World(self.escenario, self.gravedad, True)
-        except AttributeError, ValueError:
+            try:
+                self.mundo = box2d.b2World(self.escenario, self.gravedad, True)
+            except ValueError:
+                print "Solo esta disponible el motor de fisica para box2d 2.0.2b1"
+                raise AttributeError("...")
+        except AttributeError:
             print "Deshabilitando modulo de fisica (no se encuentra instalado pybox2d en este equipo)"
             self.mundo = None
             return
 
         self.i = 0
-        self.crear_techo(area)
-        self.crear_suelo(area)
-        self.crear_paredes(area)
+        self.crear_bordes_del_escenario()
         self.figuras_a_eliminar = []
+
+    def crear_bordes_del_escenario(self):
+        self.crear_techo(self.area)
+        self.crear_suelo(self.area)
+        self.crear_paredes(self.area)
+
+    def reiniciar(self):
+        for x in self.mundo.bodyList:
+            self.mundo.DestroyBody(x)
+        self.crear_bordes_del_escenario()
         
     def actualizar(self):
         if self.mundo:
@@ -89,7 +102,7 @@ class Fisica(object):
         self.suelo = Rectangulo(0, -alto/2, ancho, 2, dinamica=False, fisica=self, restitucion=restitucion)
 
     def crear_techo(self, (ancho, alto), restitucion=0):
-        self.suelo = Rectangulo(0, alto/2, ancho, 2, dinamica=False, fisica=self, restitucion=restitucion)
+        self.techo = Rectangulo(0, alto/2, ancho, 2, dinamica=False, fisica=self, restitucion=restitucion)
         
     def crear_paredes(self, (ancho, alto), restitucion=0):
         self.pared_izquierda = Rectangulo(-ancho/2, 0, 2, alto, dinamica=False, fisica=self, restitucion=restitucion)
@@ -99,6 +112,11 @@ class Fisica(object):
         if self.suelo:
             self.suelo.eliminar()
             self.suelo = None
+
+    def eliminar_techo(self):
+        if self.techo:
+            self.techo.eliminar()
+            self.techo = None
             
     def eliminar_paredes(self):
         if self.pared_izquierda:
@@ -282,7 +300,7 @@ class ConstanteDeDistancia():
             raise Exception("Las dos figuras tienen que ser objetos de la clase Figura.")
         
         constante = box2d.b2DistanceJointDef()
-        constante.Initialize(c._cuerpo, c1._cuerpo, (0,0), (0,0))
+        constante.Initialize(figura_1._cuerpo, figura_2._cuerpo, (0,0), (0,0))
         constante.collideConnected = True
         fisica.mundo.CreateJoint(constante)
 
