@@ -165,6 +165,9 @@ class QtGrilla(QtImagen):
         self.definir_cuadro(cuadro_actual)
         return ha_reiniciado
 
+    def obtener_cuadro(self):
+        return self._cuadro
+
     def dibujarse_sobre_una_pizarra(self, pizarra, x, y):
         pizarra.pintar_parte_de_imagen(self, self.dx, self.dy, self.cuadro_ancho, self.cuadro_alto, x, y)
 
@@ -804,6 +807,7 @@ class QtBase(motor.Motor):
 
         return ancho, alto
 
+
     def alternar_pausa(self):
         if self.pausa_habilitada:
             self.pausa_habilitada = False
@@ -812,6 +816,11 @@ class QtBase(motor.Motor):
             self.pausa_habilitada = True
             self.actor_pausa = actores.Pausa()
 
+    def ocultar_puntero_del_mouse(self):
+        bitmap = QtGui.QBitmap(1, 1)
+        nuevo_cursor = QtGui.QCursor(bitmap, bitmap)
+        self.setCursor(QtGui.QCursor(nuevo_cursor))
+
 class Qt(QtBase, QWidget):
 
     def __init__(self):
@@ -827,6 +836,5 @@ class QtGL(QtBase, QGLWidget):
         QGLWidget.__init__(self)
         QtBase.__init__(self)
 
-
 if QGLWidget == object:
     QtGL = Qt
